<?php

/**
 * @file
 *
 * Parish info configuration form.
 */

/**
 * Parish information configuration form.
 */
function parish_info_configuration_form() {
  $form['description'] = array(
    '#markup' => '<p>' . t('You can manage settings for parish information on this page.') . '</p>',
  );

  $form['parish_info_parish_website'] = array(
    '#type' => 'checkbox',
    '#title' => t('This is a parish website.'),
    '#default_value' => variable_get('parish_info_parish_website', 1),
  );

  $form['parish_bulk_info'] = array(
    '#type' => 'item',
    '#markup' => t("There is currently no interface for adding multiple parishes (for, as an example, a diocesan website). This feature is coming soon."),
    '#states' => array(
      'invisible' => array(
        'input[name="parish_info_parish_website"]' => array('checked' => TRUE),
      ),
    ),
  );

  $form['parish_info'] = array(
    '#type' => 'fieldset',
    '#title' => t("Information for !site", array('!site' => variable_get('site_name'))),
    '#tree' => TRUE,
    '#states' => array(
      'invisible' => array(
        'input[name="parish_info_parish_website"]' => array('checked' => FALSE),
      ),
    ),
  );

  // Attach parish information form.
  $form = parish_info_form($form);

  return system_settings_form($form);
}

/**
 * Returns an array of US States, with 2-digit abbreviations as keys.
 */
function _parish_info_list_us_states() {
  return array(
    'AL' => 'Alabama',
    'AK' => 'Alaska',
    'AZ' => 'Arizona',
    'AR' => 'Arkansas',
    'CA' => 'California',
    'CO' => 'Colorado',
    'CT' => 'Connecticut',
    'DE' => 'Delaware',
    'DC' => 'District Of Columbia',
    'FL' => 'Florida',
    'GA' => 'Georgia',
    'HI' => 'Hawaii',
    'ID' => 'Idaho',
    'IL' => 'Illinois',
    'IN' => 'Indiana',
    'IA' => 'Iowa',
    'KS' => 'Kansas',
    'KY' => 'Kentucky',
    'LA' => 'Louisiana',
    'ME' => 'Maine',
    'MD' => 'Maryland',
    'MA' => 'Massachusetts',
    'MI' => 'Michigan',
    'MN' => 'Minnesota',
    'MS' => 'Mississippi',
    'MO' => 'Missouri',
    'MT' => 'Montana',
    'NE' => 'Nebraska',
    'NV' => 'Nevada',
    'NH' => 'New Hampshire',
    'NJ' => 'New Jersey',
    'NM' => 'New Mexico',
    'NY' => 'New York',
    'NC' => 'North Carolina',
    'ND' => 'North Dakota',
    'OH' => 'Ohio',
    'OK' => 'Oklahoma',
    'OR' => 'Oregon',
    'PA' => 'Pennsylvania',
    'RI' => 'Rhode Island',
    'SC' => 'South Carolina',
    'SD' => 'South Dakota',
    'TN' => 'Tennessee',
    'TX' => 'Texas',
    'UT' => 'Utah',
    'VT' => 'Vermont',
    'VA' => 'Virginia',
    'WA' => 'Washington',
    'WV' => 'West Virginia',
    'WI' => 'Wisconsin',
    'WY' => 'Wyoming',
  );
}

/**
 * Returns an array of US Dioceses, keyed by arbitrary ID.
 *
 * There's currently no standardized identification system for dioceses, and
 * since there are many different naming conventions, we've given an arbitrary
 * ID to each one. We've chosen to leave out the 'Arch/Diocese of' for all the
 * names to save space and create more uniformity.
 *
 * We've adapted this list from the list on Open Source Catholic:
 * http://www.opensourcecatholic.com/wiki/117/php-array-list-all-united
 */
function _parish_info_list_us_dioceses() {
  return array(
    1 => 'Albany',
    2 => 'Alexandria',
    3 => 'Allentown',
    4 => 'Altoona-Johnstown',
    5 => 'Amarillo',
    6 => 'Anchorage',
    7 => 'Arlington',
    8 => 'Atlanta',
    9 => 'Austin',
    10 => 'Baker',
    11 => 'Baltimore',
    12 => 'Baton Rouge',
    13 => 'Beaumont',
    14 => 'Belleville',
    15 => 'Biloxi',
    16 => 'Birmingham',
    17 => 'Bismarck',
    18 => 'Boise',
    19 => 'Boston',
    20 => 'Bridgeport',
    21 => 'Brooklyn',
    22 => 'Brownsville',
    23 => 'Buffalo',
    24 => 'Burlington',
    25 => 'Camden',
    26 => 'Charleston',
    27 => 'Charlotte',
    28 => 'Cheyenne',
    29 => 'Chicago',
    30 => 'Cincinnati',
    31 => 'Cleveland',
    32 => 'Colorado Springs',
    33 => 'Columbus',
    34 => 'Corpus Christi',
    35 => 'Covington',
    36 => 'Crookston',
    37 => 'Dallas',
    38 => 'Davenport',
    39 => 'Denver',
    40 => 'Des Moines',
    41 => 'Detroit',
    42 => 'Dodge City',
    43 => 'Dubuque',
    44 => 'Duluth',
    45 => 'Edmonton (Cananda)',
    46 => 'El Paso',
    47 => 'Erie',
    48 => 'Evansville',
    49 => 'Fairbanks',
    50 => 'Fall River',
    51 => 'Fargo',
    52 => 'Fort Wayne-South Bend',
    53 => 'Fort Worth',
    54 => 'Fresno',
    55 => 'Gallup',
    56 => 'Galveston-Houston',
    57 => 'Gary',
    58 => 'Gaylord',
    59 => 'Grand Island',
    60 => 'Grand Rapids',
    61 => 'Great Falls-Billings',
    62 => 'Green Bay',
    63 => 'Greensburg',
    64 => 'Harrisburg',
    65 => 'Hartford',
    66 => 'Helena',
    67 => 'Honolulu',
    68 => 'Houma-Thibodaux',
    69 => 'Indianapolis',
    70 => 'Jackson',
    71 => 'Jefferson City',
    72 => 'Joliet',
    73 => 'Juneau',
    74 => 'Kalamazoo',
    75 => 'Kansas City',
    76 => 'Kansas City-St. Joseph',
    77 => 'Knoxville',
    78 => 'La Crosse',
    79 => 'Lafayette',
    80 => 'Lafayette in Indiana',
    81 => 'Lake Charles',
    82 => 'Lansing',
    83 => 'Laredo',
    84 => 'Las Cruces',
    85 => 'Las Vegas',
    86 => 'Lexington',
    87 => 'Lincoln',
    88 => 'Little Rock',
    89 => 'Los Angeles',
    90 => 'Louisville',
    91 => 'Lubbock',
    92 => 'Madison',
    93 => 'Manchester',
    94 => 'Marquette',
    95 => 'Memphis',
    96 => 'Metuchen',
    97 => 'Miami',
    98 => 'Military Services',
    99 => 'Milwaukee',
    100 => 'Mobile',
    101 => 'Monterey',
    102 => 'Nashville',
    103 => 'New Orleans',
    104 => 'New Ulm',
    105 => 'New York',
    106 => 'Newark',
    107 => 'Newton for Melkites',
    108 => 'Norwich',
    109 => 'Oakland',
    110 => 'Ogdensburg',
    111 => 'Oklahoma City',
    112 => 'Omaha',
    113 => 'Orange',
    114 => 'Orlando',
    115 => 'Our Lady of Deliverance of Newark for Syrians',
    116 => 'Our Lady of Lebanon of L.A. for Maronites',
    117 => 'Owensboro',
    118 => 'Palm Beach',
    119 => 'Paterson',
    120 => 'Pensacola-Tallahassee',
    121 => 'Peoria',
    122 => 'Philadelphia',
    123 => 'Philadelphia for Ukrainians',
    124 => 'Phoenix',
    125 => 'Pittsburgh',
    126 => 'Portland in Maine',
    127 => 'Portland in Oregon',
    128 => 'Providence',
    129 => 'Pueblo',
    130 => 'Raleigh',
    131 => 'Rapid City',
    132 => 'Reno',
    133 => 'Richmond',
    134 => 'Rochester',
    135 => 'Rockford',
    136 => 'Rockville Centre',
    137 => 'Sacramento',
    138 => 'Saginaw',
    139 => 'Salina',
    140 => 'Salt Lake City',
    141 => 'San Angelo',
    142 => 'San Antonio',
    143 => 'San Bernardino',
    144 => 'San Diego',
    145 => 'San Francisco',
    146 => 'San Jose',
    147 => 'Santa Fe',
    148 => 'Santa Rosa',
    149 => 'Savannah',
    150 => 'Scranton',
    151 => 'Seattle',
    152 => 'Shreveport',
    153 => 'Sioux City',
    154 => 'Sioux Falls',
    155 => 'Spokane',
    156 => 'Springfield in Illinois',
    157 => 'Springfield in Massachusetts',
    158 => 'Springfield-Cape Girardeau',
    159 => 'St. Augustine',
    160 => 'St. Cloud',
    161 => 'St. Josaphat of Parma for Ukrainians',
    162 => 'St. Louis',
    163 => 'St. Maron of Brooklyn for the Maronites',
    164 => 'St. Nicholas of Chicago for Ukrainians',
    165 => 'St. Paul-Minneapolis',
    166 => 'St. Petersburg',
    167 => 'St. Thomas the Apostle of Chicago-Syro-Malabars',
    168 => 'St. Thomas, VI',
    169 => 'Stamford for Ukrainians',
    170 => 'Steubenville',
    171 => 'Stockton',
    172 => 'Superior',
    173 => 'Syracuse',
    174 => 'Toledo',
    175 => 'Trenton',
    176 => 'Tucson',
    177 => 'Tulsa',
    178 => 'Tyler',
    179 => 'Venice',
    180 => 'Victoria',
    181 => 'Washington',
    182 => 'Wheeling-Charleston',
    183 => 'Wichita',
    184 => 'Wilmington',
    185 => 'Winona',
    186 => 'Worcester',
    187 => 'Yakima',
    188 => 'Youngstown',
  );
}
