<?php

/******************************************************************************
* CORE HOOKS
******************************************************************************/

/**
 * Implements hook_install_tasks().
 *
 * Add a step to the installation process to allow entry of parish information.
 */
function openparish_install_tasks() {
  $tasks['parish_info'] = array(
    'display_name' => st('Add Parish Information'),
    'display' => TRUE,
    'type' => 'form',
    'function' => 'openparish_install_parish_data_form',
  );

  return $tasks;
}

/**
 * Implements hook_block_info().
 */
function openparish_block_info() {
  // Footer block.
  $blocks['footer'] = array(
    'info' => t('Open Parish Footer'),
    'visibility' => BLOCK_VISIBILITY_NOTLISTED,
  );

  return $blocks;
}

/**
 * Implements hook_block_view().
 */
function openparish_block_view($delta) {
  global $user;

  // Footer block.
  if ($delta == 'footer') {
    $login = ($user->uid == 0) ? l(t('User Login'), 'user') : l(t('Log out'), 'user/logout');
    return array(
      'subject' => NULL,
      'content' => '<p style="text-align: center;">' . t('&copy; @year !site_name. !login.', array(
        '@year' => date('Y'),
        '!site_name' => variable_get('site_name'),
        '!login' => $login,
      )) . '</p>',
    );
  }
}

/******************************************************************************
* FORM ALTERS
******************************************************************************/

/**
 * Implements hook_form_FORM_ID_alter().
 *
 * Allows the profile to alter the site configuration form.
 */
function openparish_form_install_configure_form_alter(&$form, $form_state) {
  // Pre-populate the site name with the server name.
  $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
}

/******************************************************************************
* HELPER FUNCTIONS
******************************************************************************/

/**
 * Form builder for installation process collection of parish data. Requires
 * parish_info.module to be present.
 */
function openparish_install_parish_data_form() {
  // Set the page title appropriately.
  drupal_set_title(t('Add Parish Information'));

  // Set up the form for this parish.
  $form['parish_info_parish_website'] = array(
    '#type' => 'value',
    '#value' => TRUE,
  );

  $form['parish_info'] = array(
    '#type' => 'fieldset',
    '#title' => t("Information for your parish"),
    '#tree' => TRUE,
  );

  // Attach parish information form.
  $form = parish_info_form($form);

  $form['actions']['#type'] = 'container';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Parish Information'),
  );

  return $form;
}
